import type { Database } from '../database';
import type { DatabaseFilter, SchemaFilter } from '../filters';
import type { Server } from '../server';
export interface AdapterVersion {
    name: string;
    version: string;
    string: string;
}
export interface QueryArgs {
    query: string;
    params?: unknown[];
    multiple?: boolean;
}
export interface QueryRowResult {
    command: string;
    rows: unknown;
    fields: unknown;
    rowCount?: number;
    affectedRows?: number;
}
export interface ListTableResult {
    schema?: string;
    name: string;
}
export declare type ListViewResult = ListTableResult;
export interface ListRoutineResult {
    schema?: string;
    routineName: string;
    routineType: string;
}
export interface ListTableColumnsResult {
    columnName: string;
    dataType: string;
}
export interface TableKeysResult {
    columnName: string;
    keyType: string;
    constraintName: string | null;
    referencedTable: string | null;
}
export declare type QueryReturn = {
    execute: () => Promise<QueryRowResult[]>;
    cancel: () => void;
};
export declare abstract class AbstractAdapter {
    readonly server: Server;
    readonly database: Database;
    version: AdapterVersion;
    constructor(server: Server, database: Database);
    abstract connect(): Promise<void>;
    disconnect(): Promise<void>;
    getVersion(): AdapterVersion;
    abstract listDatabases(filter?: DatabaseFilter): Promise<string[]>;
    listSchemas(filter: SchemaFilter): Promise<string[]>;
    abstract listTables(filter: SchemaFilter): Promise<ListTableResult[]>;
    listViews(filter: SchemaFilter): Promise<ListViewResult[]>;
    listRoutines(filter: SchemaFilter): Promise<ListRoutineResult[]>;
    abstract listTableColumns(table: string, schema?: string): Promise<ListTableColumnsResult[]>;
    listTableTriggers(table: string, schema?: string): Promise<string[]>;
    listTableIndexes(table: string, schema?: string): Promise<string[]>;
    getTableReferences(table: string, schema?: string): Promise<string[]>;
    getTableKeys(table: string, schema?: string): Promise<TableKeysResult[]>;
    getQuerySelectTop(table: string, limit: number, schema?: string): string;
    getTableCreateScript(table: string, schema?: string): Promise<string[]>;
    getViewCreateScript(view: string, schema?: string): Promise<string[]>;
    getRoutineCreateScript(routine: string, type: string, schema?: string): Promise<string[]>;
    truncateAllTables(schema?: string): Promise<void>;
    abstract query(queryText: string): QueryReturn;
    abstract executeQuery(queryText: string): Promise<QueryRowResult[]>;
    abstract wrapIdentifier(value: string): string;
}
