import * as cassandra from 'cassandra-driver';
import { Database } from '../database';
import { Server } from '../server';
import { AbstractAdapter, QueryRowResult } from './abstract_adapter';
declare module 'cassandra-driver' {
    namespace metadata {
        interface Metadata {
            keyspaces: {
                [name: string]: {
                    name: string;
                    strategy: string;
                };
            };
        }
    }
}
interface Config {
    contactPoints: string[];
    protocolOptions: {
        port?: number;
    };
    keyspace?: string;
    authProvider?: cassandra.auth.PlainTextAuthProvider;
}
/**
 * To keep compatibility with the other clients we treat keyspaces as database.
 */
export default class CassandraAdapter extends AbstractAdapter {
    client: cassandra.Client;
    constructor(server: Server, database: Database);
    configDatabase(): Config;
    connect(): Promise<void>;
    disconnect(): Promise<void>;
    listDatabases(): Promise<string[]>;
    listTables(): Promise<{
        name: string;
    }[]>;
    listTableColumns(table: string): Promise<{
        columnName: string;
        dataType: string;
    }[]>;
    getTableKeys(table: string): Promise<{
        constraintName: null;
        columnName: string;
        referencedTable: null;
        keyType: string;
    }[]>;
    truncateAllTables(): Promise<void>;
    query(): never;
    executeQuery(queryText: string): Promise<QueryRowResult[]>;
    wrapIdentifier(value: string): string;
}
export declare function wrapIdentifier(value: string): string;
export {};
