"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.adapterFactory = exports.registerAdapter = exports.ADAPTERS = void 0;
const cassandra_1 = __importDefault(require("./cassandra"));
const mysql_1 = __importDefault(require("./mysql"));
const postgresql_1 = __importDefault(require("./postgresql"));
const sqlite_1 = __importDefault(require("./sqlite"));
const sqlserver_1 = __importDefault(require("./sqlserver"));
/**
 * List of supported database adapters
 */
exports.ADAPTERS = [
    {
        key: 'mysql',
        protocol: 'mysql',
        name: 'MySQL',
        adapter: mysql_1.default,
        defaultPort: 3306,
        disabledFeatures: ['server:schema', 'server:domain'],
    },
    {
        key: 'mariadb',
        protocol: 'mariadb',
        name: 'MariaDB',
        adapter: mysql_1.default,
        defaultPort: 3306,
        disabledFeatures: ['server:schema', 'server:domain'],
    },
    {
        key: 'postgresql',
        protocol: 'postgres',
        name: 'PostgreSQL',
        adapter: postgresql_1.default,
        defaultDatabase: 'postgres',
        defaultPort: 5432,
        disabledFeatures: ['server:domain'],
    },
    {
        key: 'redshift',
        protocol: 'redshift',
        name: 'Redshift',
        adapter: postgresql_1.default,
        defaultDatabase: 'postgres',
        defaultPort: 5432,
        disabledFeatures: ['server:domain'],
    },
    {
        key: 'sqlserver',
        protocol: 'mssql',
        name: 'Microsoft SQL Server',
        adapter: sqlserver_1.default,
        defaultPort: 1433,
        disabledFeatures: [],
    },
    {
        key: 'sqlite',
        protocol: 'file',
        name: 'SQLite',
        adapter: sqlite_1.default,
        defaultDatabase: ':memory:',
        disabledFeatures: [
            'server:ssl',
            'server:host',
            'server:port',
            'server:socketPath',
            'server:user',
            'server:password',
            'server:schema',
            'server:domain',
            'server:ssh',
            'cancelQuery',
        ],
    },
    {
        key: 'cassandra',
        protocol: 'cassandra',
        name: 'Cassandra',
        adapter: cassandra_1.default,
        defaultPort: 9042,
        disabledFeatures: [
            'server:ssl',
            'server:socketPath',
            'server:schema',
            'server:domain',
            'scriptCreateTable',
            'cancelQuery',
        ],
    },
];
function registerAdapter(adapter) {
    if (exports.ADAPTERS.find((a) => adapter.key === a.key)) {
        throw new Error(`Adapter already registered with that key`);
    }
    exports.ADAPTERS.push(adapter);
}
exports.registerAdapter = registerAdapter;
function adapterFactory(adapterKey, server, database) {
    const adapter = exports.ADAPTERS.find((a) => a.key === adapterKey);
    if (!adapter) {
        throw new Error(`Unknown requested adapter: ${adapterKey}`);
    }
    return new adapter.adapter(server, database);
}
exports.adapterFactory = adapterFactory;
