import mysql from 'mysql2';
import { AbstractAdapter } from './abstract_adapter';
import type { QueryArgs, QueryRowResult, QueryReturn, ListTableResult, ListViewResult, ListRoutineResult, ListTableColumnsResult, TableKeysResult } from './abstract_adapter';
import type { Database } from '../database';
import type { DatabaseFilter } from '../filters';
import type { Server } from '../server';
declare module 'mysql2' {
    interface PoolConnection {
        _fatalError: Error | null;
        _protocolError: Error | null;
    }
}
interface QueryResult {
    data: mysql.RowDataPacket[] | mysql.RowDataPacket[][] | mysql.ResultSetHeader;
    fields: mysql.FieldPacket[] | mysql.FieldPacket[][];
}
interface Config {
    host?: string;
    port?: number;
    user?: string;
    password?: string;
    database?: string;
    multipleStatements: true;
    dateStrings: true;
    supportBigNumbers: true;
    bigNumberStrings: true;
    ssl?: {
        rejectUnauthorized: false;
    };
}
export default class MysqlAdapter extends AbstractAdapter {
    conn: {
        pool: mysql.Pool;
    };
    constructor(server: Server, database: Database);
    configDatabase(): Config;
    connect(): Promise<void>;
    disconnect(): Promise<void>;
    query(queryText: string): QueryReturn;
    executeQuery(queryText: string, connection?: mysql.PoolConnection): Promise<QueryRowResult[]>;
    listTables(): Promise<ListTableResult[]>;
    listViews(): Promise<ListViewResult[]>;
    listRoutines(): Promise<ListRoutineResult[]>;
    listTableColumns(table: string): Promise<ListTableColumnsResult[]>;
    listTableTriggers(table: string): Promise<string[]>;
    listTableIndexes(table: string): Promise<string[]>;
    listDatabases(filter?: DatabaseFilter): Promise<string[]>;
    getTableReferences(table: string): Promise<string[]>;
    getTableKeys(table: string): Promise<TableKeysResult[]>;
    getTableCreateScript(table: string): Promise<string[]>;
    getViewCreateScript(view: string): Promise<string[]>;
    getRoutineCreateScript(routine: string, type: string): Promise<string[]>;
    getSchema(connection?: mysql.PoolConnection): Promise<string>;
    truncateAllTables(): Promise<void>;
    driverExecuteQuery(queryArgs: QueryArgs, connection?: mysql.PoolConnection): Promise<QueryResult>;
    runWithConnection<T = QueryResult>(run: (connection: mysql.PoolConnection) => Promise<T>): Promise<T>;
    wrapIdentifier(value: string): string;
}
export declare function wrapIdentifier(value: string): string;
export {};
