import pg from 'pg';
import { AbstractAdapter, QueryArgs, QueryRowResult, TableKeysResult } from './abstract_adapter';
import type { Database } from '../database';
import type { DatabaseFilter, SchemaFilter } from '../filters';
import type { Server } from '../server';
import type { QueryReturn, ListTableResult, ListViewResult, ListRoutineResult, ListTableColumnsResult } from './abstract_adapter';
interface AdapterConfig {
    host?: string;
    port?: number;
    user?: string;
    password?: string;
    database: string;
    max: 5;
    ssl?: {
        key?: string;
        ca?: string;
        cert?: string;
        rejectUnauthorized?: boolean;
    };
}
export default class PostgresqlAdapter extends AbstractAdapter {
    conn: {
        pool: pg.Pool;
    };
    defaultSchema: string;
    constructor(server: Server, database: Database);
    configDatabase(): AdapterConfig;
    connect(): Promise<void>;
    disconnect(): Promise<void>;
    getSchema(): Promise<string>;
    listDatabases(filter?: DatabaseFilter): Promise<string[]>;
    listTables(filter: SchemaFilter): Promise<ListTableResult[]>;
    listViews(filter: SchemaFilter): Promise<ListViewResult[]>;
    listRoutines(filter: SchemaFilter): Promise<ListRoutineResult[]>;
    listTableColumns(table: string, schema?: string): Promise<ListTableColumnsResult[]>;
    listTableTriggers(table: string, schema?: string): Promise<string[]>;
    listTableIndexes(table: string, schema?: string): Promise<string[]>;
    listSchemas(filter: SchemaFilter): Promise<string[]>;
    getTableReferences(table: string, schema?: string): Promise<string[]>;
    getTableKeys(table: string, schema?: string): Promise<TableKeysResult[]>;
    getQuerySelectTop(table: string, limit: number, schema?: string): string;
    getTableCreateScript(table: string, schema?: string): Promise<string[]>;
    getViewCreateScript(view: string, schema?: string): Promise<string[]>;
    getRoutineCreateScript(routine: string, type: string, schema?: string): Promise<string[]>;
    truncateAllTables(schema?: string): Promise<void>;
    query(queryText: string): QueryReturn;
    executeQuery(queryText: string, connection?: pg.PoolClient): Promise<QueryRowResult[]>;
    driverExecuteSingleQuery<T>(queryArgs: QueryArgs, connection?: pg.PoolClient): Promise<pg.QueryResult<T>>;
    driverExecuteQuery(queryArgs: QueryArgs, connection?: pg.PoolClient): Promise<pg.QueryResult[]>;
    runWithConnection<T = pg.QueryResult[]>(run: (connection: pg.PoolClient) => Promise<T>): Promise<T>;
    wrapIdentifier(value: string): string;
}
export declare function wrapIdentifier(value: string): string;
export {};
