import sqlite3 from 'sqlite3';
import { Result } from 'sql-query-identifier';
import { AbstractAdapter } from './abstract_adapter';
import type { QueryArgs, QueryRowResult, QueryReturn, ListTableColumnsResult, ListTableResult, ListViewResult } from './abstract_adapter';
import type { Server } from '../server';
import type { Database } from '../database';
interface QueryResult {
    data?: unknown[];
    lastID: number;
    changes: number;
    statement: Result;
}
export default class SqliteAdapter extends AbstractAdapter {
    conn: {
        dbConfig: {
            database: string;
        };
    };
    constructor(server: Server, database: Database);
    configDatabase(): {
        database: string;
    };
    connect(): Promise<void>;
    query(queryText: string): QueryReturn;
    executeQuery(queryText: string, connection?: sqlite3.Database): Promise<QueryRowResult[]>;
    listTables(filter: unknown, connection?: sqlite3.Database): Promise<ListTableResult[]>;
    listViews(): Promise<ListViewResult[]>;
    listTableColumns(table: string): Promise<ListTableColumnsResult[]>;
    listTableTriggers(table: string): Promise<string[]>;
    listTableIndexes(table: string): Promise<string[]>;
    listDatabases(): Promise<string[]>;
    getTableCreateScript(table: string): Promise<string[]>;
    getViewCreateScript(view: string): Promise<string[]>;
    truncateAllTables(): Promise<void>;
    driverExecuteQuery(queryArgs: QueryArgs, connection?: sqlite3.Database): Promise<QueryResult | QueryResult[]>;
    runWithConnection<T>(run: (conn: sqlite3.Database) => Promise<T>): Promise<T>;
    wrapIdentifier(value: string): string;
}
export declare function wrapIdentifier(value: string): string;
export {};
