import { ConnectionPool } from 'mssql';
import { AbstractAdapter, QueryArgs, QueryRowResult } from './abstract_adapter';
import type { config, Request, IResult, IRecordSet } from 'mssql';
import type { Database } from '../database';
import type { DatabaseFilter, SchemaFilter } from '../filters';
import type { Server } from '../server';
import type { ListTableResult, ListViewResult, ListRoutineResult, ListTableColumnsResult, TableKeysResult, QueryReturn } from './abstract_adapter';
interface QueryResult<T = unknown> {
    request: Request;
    result: IResult<unknown>;
    data: IRecordSet<T>[];
}
interface SingleQueryResult<T = unknown> {
    request: Request;
    result: IResult<unknown>;
    data: IRecordSet<T>;
}
export default class SqlServerAdapter extends AbstractAdapter {
    conn: {
        dbConfig: config;
        connection?: ConnectionPool;
    };
    constructor(server: Server, database: Database);
    configDatabase(): config;
    connect(): Promise<void>;
    disconnect(): Promise<void>;
    getSchema(connection?: ConnectionPool): Promise<string>;
    listDatabases(filter?: DatabaseFilter): Promise<string[]>;
    listSchemas(filter: SchemaFilter): Promise<string[]>;
    listTables(filter: SchemaFilter): Promise<ListTableResult[]>;
    listViews(filter: SchemaFilter): Promise<ListViewResult[]>;
    listRoutines(filter: SchemaFilter): Promise<ListRoutineResult[]>;
    listTableColumns(table: string): Promise<ListTableColumnsResult[]>;
    listTableTriggers(table: string): Promise<string[]>;
    listTableIndexes(table: string): Promise<string[]>;
    getTableReferences(table: string): Promise<string[]>;
    getTableKeys(table: string): Promise<TableKeysResult[]>;
    getQuerySelectTop(table: string, limit: number): string;
    getTableCreateScript(table: string): Promise<string[]>;
    getViewCreateScript(view: string): Promise<string[]>;
    getRoutineCreateScript(routine: string): Promise<string[]>;
    truncateAllTables(): Promise<void>;
    query(queryText: string): QueryReturn;
    executeQuery(queryText: string, connection?: ConnectionPool): Promise<QueryRowResult[]>;
    driverExecuteSingleQuery<T = unknown>(queryArgs: QueryArgs, connection?: ConnectionPool): Promise<SingleQueryResult<T>>;
    driverExecuteQuery<T = unknown>(queryArgs: QueryArgs, connection?: ConnectionPool): Promise<QueryResult<T>>;
    runWithConnection<T = QueryResult>(run: (connection: ConnectionPool) => Promise<T>): Promise<T>;
    wrapIdentifier(value: string): string;
}
export declare function wrapIdentifier(value: string): string;
export {};
