import type { DatabaseFilter, SchemaFilter } from './filters';
import type { Server } from './server';
import type { AbstractAdapter, AdapterVersion, QueryRowResult } from './adapters/abstract_adapter';
export declare class Database {
    server: Server;
    database: string | undefined;
    connecting: boolean;
    connection: null | AbstractAdapter;
    constructor(server: Server, database?: string);
    handleSSHError(): Promise<void>;
    checkIsConnected(): void;
    connect(): Promise<void>;
    disconnect(): void;
    getVersion(): AdapterVersion;
    listDatabases(filter?: DatabaseFilter): Promise<string[]>;
    listSchemas(filter: SchemaFilter): Promise<string[]>;
    listTables(filter: SchemaFilter): Promise<{
        name: string;
    }[]>;
    listViews(filter: SchemaFilter): Promise<{
        name: string;
    }[]>;
    listRoutines(filter: SchemaFilter): Promise<{
        schema?: string;
        routineName: string;
        routineType: string;
    }[]>;
    listTableColumns(table: string, schema?: string): Promise<{
        columnName: string;
        dataType: string;
    }[]>;
    listTableTriggers(table: string, schema?: string): Promise<string[]>;
    listTableIndexes(table: string, schema?: string): Promise<string[]>;
    getTableReferences(table: string, schema?: string): Promise<string[]>;
    getTableKeys(table: string, schema?: string): Promise<{
        columnName: string;
        keyType: string;
        constraintName: string | null;
        referencedTable: string | null;
    }[]>;
    query(queryText: string): {
        execute: () => Promise<QueryRowResult[]>;
        cancel: () => void;
    };
    executeQuery(queryText: string): Promise<QueryRowResult[]>;
    getQuerySelectTop(table: string, schema?: string, limit?: number): Promise<string>;
    getTableCreateScript(table: string, schema?: string): Promise<string[]>;
    getTableSelectScript(table: string, schema?: string): Promise<string>;
    getTableInsertScript(table: string, schema?: string): Promise<string>;
    getTableUpdateScript(table: string, schema?: string): Promise<string>;
    getTableDeleteScript(table: string, schema?: string): Promise<string>;
    getViewCreateScript(view: string, schema?: string): Promise<string[]>;
    getRoutineCreateScript(routine: string, type: string, schema?: string): Promise<string[]>;
    truncateAllTables(schema?: string): Promise<void>;
    getTableColumnNames(table: string, schema?: string): Promise<string[]>;
    resolveSchema(schema?: string): string;
    wrap(identifier: string): string;
}
export declare function clearSelectLimit(): void;
export declare function setSelectLimit(limit: number): void;
