"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.setLogger = void 0;
const debug_1 = __importDefault(require("debug"));
const loggers = {};
function createLogger(namespace) {
    if (!namespace) {
        throw new Error('Missing log namespace');
    }
    if (loggers[namespace]) {
        throw new Error('This logger is already registered');
    }
    // default logger
    const debugLogger = debug_1.default(`sqlectron-core:${namespace}`);
    loggers[namespace] = {
        debug: debugLogger.bind(debugLogger),
        error: debugLogger.bind(debugLogger),
    };
    // The logger is loaded through a function
    // so is possible to access a new logger
    // defined with setLogger
    return () => loggers[namespace];
}
exports.default = createLogger;
/**
 * Allow use a different logger
 */
function setLogger(customLogger) {
    Object.keys(loggers).forEach((logger) => {
        loggers[logger] = customLogger(logger);
    });
}
exports.setLogger = setLogger;
