/// <reference types="node" />
import type { Server as NetServer } from 'net';
import { Database } from './database';
export interface LegacyServerConfig {
    name: string;
    client?: string;
    adapter?: string;
    host?: string;
    socketPath?: string;
    port?: number;
    localHost?: string;
    localPort?: number;
    user?: string;
    password?: string;
    applicationName?: string;
    domain?: string;
    ssh?: {
        user: string;
        password?: string;
        passphrase?: string;
        privateKey?: string;
        host: string;
        port: number;
        useAgent?: boolean;
    };
    ssl?: {
        key?: string;
        ca?: string;
        cert?: string;
    } | false;
}
export interface ServerConfig extends LegacyServerConfig {
    adapter: string;
}
export declare class Server {
    databases: {
        [key: string]: Database;
    };
    config: ServerConfig;
    sshTunnel: null | NetServer;
    constructor(serverConfig: ServerConfig);
    db(dbName: string): Database;
    /**
     * Disconnect all connected databases
     */
    end(): void;
    createConnection(dbName?: string): Database;
    removeDatabase(dbName?: string): void;
}
export declare function createServer(serverConfig: LegacyServerConfig): Server;
