"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createServer = exports.Server = void 0;
const database_1 = require("./database");
const adapters_1 = require("./adapters");
class Server {
    constructor(serverConfig) {
        this.databases = {};
        this.sshTunnel = null;
        this.config = {
            ...serverConfig,
            host: serverConfig.host || serverConfig.socketPath,
        };
    }
    db(dbName) {
        return this.databases[dbName];
    }
    /**
     * Disconnect all connected databases
     */
    end() {
        for (const dbName in this.databases) {
            this.databases[dbName].disconnect();
        }
        // close SSH tunnel
        if (this.sshTunnel) {
            this.sshTunnel.close();
            this.sshTunnel = null;
        }
    }
    createConnection(dbName) {
        const dbKey = dbName || 'undefined';
        if (this.databases[dbKey]) {
            return this.databases[dbKey];
        }
        this.databases[dbKey] = new database_1.Database(this, dbName);
        return this.databases[dbKey];
    }
    removeDatabase(dbName) {
        const dbKey = dbName || 'undefined';
        if (this.databases[dbKey]) {
            delete this.databases[dbKey];
        }
    }
}
exports.Server = Server;
function createServer(serverConfig) {
    if (!serverConfig) {
        throw new Error('Missing server configuration');
    }
    if (!serverConfig.adapter && serverConfig.client) {
        serverConfig.adapter = serverConfig.client;
    }
    const config = serverConfig;
    if (!adapters_1.ADAPTERS.some((adapter) => adapter.key === config.adapter)) {
        throw new Error(`Invalid SQL adapter: ${config.adapter}`);
    }
    return new Server(config);
}
exports.createServer = createServer;
